pysradb package
===============

Submodules
----------

pysradb.basedb module
---------------------

.. automodule:: pysradb.basedb
    :members:
    :undoc-members:
    :show-inheritance:

pysradb.cli module
------------------

.. automodule:: pysradb.cli
    :members:
    :undoc-members:
    :show-inheritance:

pysradb.filter\_attrs module
----------------------------

.. automodule:: pysradb.filter_attrs
    :members:
    :undoc-members:
    :show-inheritance:

pysradb.geodb module
--------------------

.. automodule:: pysradb.geodb
    :members:
    :undoc-members:
    :show-inheritance:

pysradb.sradb module
--------------------

.. automodule:: pysradb.sradb
    :members:
    :undoc-members:
    :show-inheritance:

pysradb.utils module
--------------------

.. automodule:: pysradb.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pysradb
    :members:
    :undoc-members:
    :show-inheritance:
